<?php
/***************************************************************
 *  Copyright notice
*
*  (c) 2013 Gerald Loß <gerald.loss@gmx.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/


/**
 * Class to define a box with one or more questions
 *
 * @author	Gerald Loß <gerald.loss@gmx.de>
 * @package	TYPO3
 * @subpackage	tx_glcrossword
 */
class tx_glcrossword_box_questions extends tx_glcrossword_box {
	
	// Constants for the direction of the question
	const C_INT_DIR_TOP_LEFT = 0;
	const C_INT_DIR_TOP = 1;
	const C_INT_DIR_TOP_RIGHT = 2;
	const C_INT_DIR_RIGHT_TOP = 3;
	const C_INT_DIR_RIGHT = 4;
	const C_INT_DIR_RIGHT_DOWN = 5;
	const C_INT_DIR_DOWN_RIGTH = 6;
	const C_INT_DIR_DOWN = 7;
	const C_INT_DIR_DOWN_LEFT = 8;
	const C_INT_DIR_LEFT_DOWN = 9;
	const C_INT_DIR_LEFT = 10;
	const C_INT_DIR_LEFT_TOP = 11;
	
	/**
	 * Max value of the direction constants.
	 * @var integer
	 */
	const C_INT_DIR_MAX = 11;
	
	
	
	
	/**
	 * Factory of an box question object. 
	 * @param integer 		$i_intX 			X position of the box in the crossword
	 * @param integer 		$i_intY 			Y position of the box in the crossword
	 * @param integer 		$i_intUID 			UID of the question in the database
	 * @param integer 		$i_intDirection 	Direction of the question
	 * @param string  		$i_strQuestion 		Question text
	 * @param string  		$i_strAnswer 		Answer text
	 * @param integer 		$i_intEditMask		Edit mask for the answer text
	 * @param tx_glcrossword_crossword	$i_objCrossword		Object of class tslib_pibase 
	 * @return tx_glcrossword_box The created box.
	 */
	public static function boxQuestionFactory($i_intX, $i_intY, $i_intUID, $i_intDirection, 
											  $i_strQuestion, $i_strAnswer, $i_intEditMask, $i_objCrossword ) {
		// new question object
		/* @var $l_objNewQuestionObject tx_glcrossword_box_questions */
		$l_objNewQuestionObject = NULL;
		// current box object if there already exist one
		/* @var $l_objCurrentBox tx_glcrossword_box */
		$l_objCurrentBox = NULL;
		// current type of this box
		$l_strCurrentType = '';
		// the current question text
		$l_strCurrentQuestionText = '';
		// temporary error text
		$l_strTempErrorText = '';
		// the current question UID
		$l_intCurrentQuestionUID = 0;
		
		// read the box of this coordinates
		$l_objCurrentBox = $i_objCrossword->getBox($i_intX, $i_intY);
		
		// if there exists no object on this coordinates
		if (! isset($l_objCurrentBox)) {
			// create it
			$l_objNewQuestionObject = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('tx_glcrossword_box_questions',
					$i_intX,
					$i_intY,
					$i_intUID,
					$i_intDirection,
					$i_strQuestion,
					$i_strAnswer,
					$i_intEditMask,
					$i_objCrossword );
			// add the new box object
			$i_objCrossword->addBox($l_objNewQuestionObject);
			
			// return the new question object
			return $l_objNewQuestionObject;
				
			
		// if there exists already an object on this coordinates
		} else {
			// read the current type
			$l_strCurrentType = $l_objCurrentBox->get_strType();
			
			// if there is no type missmatch
			if ($l_strCurrentType == tx_glcrossword_box::C_STR_TYPE_QUESTION) {
				
				// add the new question to this box
				$l_objCurrentBox->addQuestion($i_intUID, $i_intDirection, $i_strQuestion, $i_strAnswer, $i_intEditMask);
				
				// return the current question object
				return $l_objCurrentBox;
				
				// if there is a type missmatch
			} else {
				// get all informations of this object for the error message
				tx_glcrossword_box::getCausingQuestionInformation($l_objCurrentBox, $l_strCurrentQuestionText, $l_intCurrentQuestionUID);
				
				// In this field is a box of type %s causing of question "%s" with UID %u
				// and a box of type %s causing of question "%s" with UID %u
				// at the same time.
				$l_strTempErrorText = $i_objCrossword->m_objPiBase->pi_getLL('code.error.box.type.missmatch', 
																			 'Two boxes with different types at the same time',
																			 false );
				$l_strTempErrorText = sprintf($l_strTempErrorText,
											 $l_strCurrentType,
											 $l_strCurrentQuestionText,
											 $l_intCurrentQuestionUID,
											 tx_glcrossword_box::C_STR_TYPE_QUESTION,
											 $i_strQuestion,
											 $i_intUID );
				
				// if the priority of this box is higher
				if ( tx_glcrossword_box::typeHasHigherPriority( $l_strCurrentType, tx_glcrossword_box::C_STR_TYPE_QUESTION)) {
					$l_objNewQuestionObject = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('tx_glcrossword_box_questions',
							$i_intX,
							$i_intY,
							$i_intUID,
							$i_intDirection,
							$i_strQuestion,
							$i_strAnswer,
							$i_intEditMask,
							$i_objCrossword );
					// replace the old box object
					$i_objCrossword->addBox($l_objNewQuestionObject);
				}
				// read now the current box object
				$l_objCurrentBox = $i_objCrossword->getBox($i_intX, $i_intY);
				// set the error flag
				$l_objCurrentBox->set_blnIsError(true);
				// set the error text
				$l_objCurrentBox->set_strErrorText($l_strTempErrorText);
				
				// return the current question object
				return $l_objCurrentBox;
			} // if there is a type missmatch
		} // if there exists already an object on this coordinates
		
	}
	
	/**
	 * Constructor of this class
	 * @param integer 		$i_intX 			X position of the box in the crossword
	 * @param integer 		$i_intY 			Y position of the box in the crossword
	 * @param integer 		$i_intUID 			UID of the question in the database
	 * @param integer 		$i_intDirection 	Direction of the question
	 * @param string  		$i_strQuestion 		Question text
	 * @param string  		$i_strAnswer 		Answer text
	 * @param integer 		$i_intEditMask		Edit mask for the answer text
	 * @param tx_glcrossword_crossword	$i_objCrossword		Object of class tslib_pibase	 
	 * @param integer		$i_intUniqueId		The unique ID of the crossword
	 */
	public function __construct($i_intX, $i_intY, $i_intUID, $i_intDirection, $i_strQuestion, $i_strAnswer, $i_intEditMask, $i_objCrossword) {
		parent::__construct($i_intX, $i_intY, tx_glcrossword_box::C_STR_TYPE_QUESTION, $i_objCrossword);
		
		// add the first question to this box
		$this->addQuestion($i_intUID, $i_intDirection, $i_strQuestion, $i_strAnswer, $i_intEditMask);
		
	}
	
	/**
	 * Adds a question to this box. 
	 * @param integer $i_intUid 		UID of the question in the database
	 * @param integer $i_intDirection 	Direction of the question
	 * @param string  $i_strQuestion 	Question text
	 * @param string  $i_strAnswer 		Answer text
	 * @param integer $i_intEditMask	Edit mask for the answer text
	 */
	public function addQuestion($i_intUid, $i_intDirection, $i_strQuestion, $i_strAnswer, $i_intEditMask) {
		
		// the error text
		$l_strErrorText = '';
		
		// create question object
		$l_objQuestion = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('tx_glcrossword_content_question',
												  $i_intUid,
												  $i_strQuestion, 	
												  $i_strAnswer,	
												  $i_intEditMask );
		
		// try to add the question with the direction as index
		// if already question with this direction exists
		if (! $this->addContent($i_intDirection, $l_objQuestion)) {
			// set error flag
			$this->set_blnIsError(true);
			// There are two questions in this box with the same direction.\n
		    // Theres ist the question "%s" with the UID %u and there is the
		    // question "%s" with the UID %u.
			$l_strErrorText = $this->m_objCrossword->m_objPiBase->pi_getLL('code.error.double.question',
																  'Error: Double questions for the same direction.',
																  false );
			$l_strErrorText = sprintf($l_strErrorText,
									  $this->getContentObject($i_intDirection)->get_strQuestion(),
									  $this->getContentObject($i_intDirection)->get_intUid(),
									  $i_strQuestion,
									  $i_intUid );
			$this->set_strErrorText($l_strErrorText);
		}
	}
	
	
	/**
	 * Getter for the question.
	 * @param integer $i_intDirection Direction of the readed answer.
	 * @return tx_glcrossword_content_question
	 */
	public function get_objQuestion($i_intDirection) {
		/* @var $l_objContentQuestion tx_glcrossword_content_question */
		$l_objContentQuestion = NULL;
		
		$l_objContentQuestion = $this->getContentObject($i_intDirection);
		
		// if direction exists
		if (isset($l_objContentQuestion)) {
			return $l_objContentQuestion;
		}
		else {
			return NULL;	
		}
	}
	
	/**
	 * Returns the first question in the question array.
	 * @param	integer	$e_intDirection					Direction of the first question.
	 * @return 			tx_glcrossword_content_question	
	 */
	public function getFirstQuestion(&$e_intDirection) {
		$l_objContentQuestion = NULL;
		for ($i = 0; $i <= self::C_INT_DIR_MAX; $i++) {
			$l_objContentQuestion = $this->get_objQuestion($i);
			if (isset($l_objContentQuestion)) {
				$e_intDirection = i;
				break;
			}
		}
		return $l_objContentQuestion;
	}
	
	/**
	 * Get the last answer box of this question in the givven direction.
	 * 
	 * @param 	integer $i_intDirection		The direction of the question.
	 * @return	tx_glcrossword_box_answer	The last answer box of this question.
	 */
	public function getLastAnswerBoxOfQuestion($i_intDirection) {
		
		$l_intAnswerLength = 0;
		
		// get the length of the answer
		$l_intAnswerLength = $this->get_objQuestion($i_intDirection)->get_intActualLength();
		
		// returns the last answer box of this question
		return $this->getBoxFromOffset($i_intDirection, $l_intAnswerLength);
	}
	
	/**
	 * Returns array with all questions of this question box.
	 * @return 	array	Array with all questions of this question box.
	 */
	public function getQuestionContentArray() {
		
		// array with the content objects
		$l_arrContent = array();
		// the current question content object
		/* @var $l_objContentQuestion tx_glcrossword_content_question */
		$l_objContentQuestion = NULL; 
		
		// looking in every direction for a question
		for ($i = 0; $i <= self::C_INT_DIR_MAX; $i++) {
			$l_objContentQuestion = $this->get_objQuestion($i);
			if (isset($l_objContentQuestion)) {
				// insert the question text into the array
				$l_arrContent[$i] = $l_objContentQuestion->get_strQuestion();
			
			// else set an empty entry into the array
			} else {
				$l_arrContent[$i] = NULL;
			}
		}
		
		return $l_arrContent;
	}
	
	/**
	 * Draws a question box in HTML
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string						Returns the generated HTML content.
	 */
	public function draw( $i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content of the qestion box
		$l_strContent = '';
		
		// get the plain box
		$l_strContent = $this->getSingleBox($i_fltXScale, $i_fltYScale, $i_intBorderWidth, 'glcrossword_question', FALSE, FALSE);
		
		return $l_strContent;
	}
	
	
	/**
	 * Draws the arrows of the Question Box. 
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string						Returns the generated HTML content.
	 */
	public function draw_arrows($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// draw the arrows for the questions
		$l_strContent .= $this->getQuestionsArrows($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
		
		return $l_strContent;
	}
	
	/**
	 * Get the arrows of the questions as HTML content.
	 * @param float $i_fltXScale Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float $i_fltYScale Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer $i_intBorderWidth Thickness of the borderlines of the box
	 * @return string The HTML content of the arrows.
	 */
	protected function getQuestionsArrows($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		
		// the HTML content
		$l_strContent = '';
		/* @var $l_objContentQuestion tx_glcrossword_content_question */
		$l_objContentQuestion = NULL;
		
		for ($i = 0; $i <= self::C_INT_DIR_MAX; $i++) {
			
			// read the content object
			$l_objContentQuestion = $this->getContentObject($i); 
			
			// if the question of direction $i exists
			if (isset($l_objContentQuestion)) {
				// get the HTML Content of the arrow of this direction
				$l_strContent .= $this->getArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $i);
			}
		}
		
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of a certain direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @param integer 	$i_intDirection 	Direction of the arrow.
	 * @return string 						The HTML content of the arrows.
	 */
	protected function getArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $i_intDirection) {
		// the HTML content
		$l_strContent = '';
		
		switch ($i_intDirection) {
			// if direction top to the left
			case self::C_INT_DIR_TOP_LEFT:
				// get the HTML content for a top to the left arrow
				$l_strContent = $this->getTopLeftArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
			
			// if direction top 
			case self::C_INT_DIR_TOP:
				// get the HTML content for a top arrow
				$l_strContent = $this->getTopArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;

			// if direction top to the right
			case self::C_INT_DIR_TOP_RIGHT:
				// get the HTML content for a top to the right arrow
				$l_strContent = $this->getTopRightArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
				
			// if direction right to the top
			case self::C_INT_DIR_RIGHT_TOP:
				// get the HTML content for a right to the top arrow
				$l_strContent = $this->getRightTopArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
					
				// if direction right
			case self::C_INT_DIR_RIGHT:
				// get the HTML content for right arrow
				$l_strContent = $this->getRightArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
			
			// if direction right to the bottom
			case self::C_INT_DIR_RIGHT_DOWN:
				// get the HTML content for a right to the bottom arrow
				$l_strContent = $this->getRightBottomArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
				
			// if direction down to the right
			case self::C_INT_DIR_DOWN_RIGTH:
				// get the HTML content for a down to the right arrow
				$l_strContent = $this->getDownRightArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
					
			// if direction down
			case self::C_INT_DIR_DOWN:
				// get the HTML content for down arrow
				$l_strContent = $this->getDownArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
			
			// if direction down to left
			case self::C_INT_DIR_DOWN_LEFT:
				// get the HTML content for a down to the left arrow
				$l_strContent = $this->getDownLeftArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
				
			// if direction left to the bottom
			case self::C_INT_DIR_LEFT_DOWN:
				// get the HTML content for a left to the bottom arrow
				$l_strContent = $this->getLeftBottomArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
					
			// if direction left
			case self::C_INT_DIR_LEFT:
				// get the HTML content for left arrow
				$l_strContent = $this->getLeftArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
			
			// if direction left to the top
			case self::C_INT_DIR_LEFT_TOP:
				// get the HTML content for a left to the top arrow
				$l_strContent = $this->getLeftTopArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth);
				break;
				
		}
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of the left to the bottom direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getLeftBottomArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow left to the bottom -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow line properties
		$l_intLeft = $l_intLeft - round(10 * $i_fltXScale);
		$l_intTop = $l_intTop + round(40 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(5 * $i_fltYScale);
	
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
				'glcrossword_line_left_top glcrossword_line_left_top_default', tx_glcrossword_box_questions::C_INT_DIR_LEFT_DOWN);
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft - round(20 * $i_fltXScale);
		$l_intTop = $l_intTop + round(45 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlDownArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												 tx_glcrossword_box_questions::C_INT_DIR_LEFT_DOWN);
	
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of the left direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getLeftArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow left -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft - round(10 * $i_fltXScale);
		$l_intTop = $l_intTop + round(20 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlLeftArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												 tx_glcrossword_box_questions::C_INT_DIR_LEFT);
	
		return $l_strContent;
	}

	/**
	 * Get the arrow of the left to the top direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getLeftTopArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow left to the top -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow line properties
		$l_intLeft = $l_intLeft - round(10 * $i_fltXScale);
		$l_intTop = $l_intTop + round(15 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(5 * $i_fltYScale);
	
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
				'glcrossword_line_left_bottom glcrossword_line_left_bottom_default', tx_glcrossword_box_questions::C_INT_DIR_LEFT_TOP);
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft - round(20 * $i_fltXScale);
		$l_intTop = $l_intTop + round(5 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlTopArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, tx_glcrossword_box_questions::C_INT_DIR_LEFT_TOP);
	
		return $l_strContent;
	}

	/**
	 * Get the arrow of the down to the right direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getDownRightArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow down to the right -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow line properties
		$l_intLeft = $l_intLeft + round(40 * $i_fltXScale);
		$l_intTop = $l_intTop + round(60 * $i_fltYScale);
		$l_intGeneralXSize = round(5 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, 
												   'glcrossword_line_left_bottom glcrossword_line_left_bottom_default', 
												   tx_glcrossword_box_questions::C_INT_DIR_DOWN_RIGTH);
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(45 * $i_fltXScale);
		$l_intTop = $l_intTop + round(61 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlRightArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												  tx_glcrossword_box_questions::C_INT_DIR_DOWN_RIGTH);
	
		return $l_strContent;
	}
	
	/**
	 * Get the down arrow.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getDownArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow down -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(20 * $i_fltXScale);
		$l_intTop = $l_intTop + round(60 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlDownArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												 tx_glcrossword_box_questions::C_INT_DIR_DOWN);
	
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of the down to the left direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getDownLeftArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow down to the left -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow line properties
		$l_intLeft = $l_intLeft + round(15 * $i_fltXScale);
		$l_intTop = $l_intTop + round(60 * $i_fltYScale);
		$l_intGeneralXSize = round(5 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, 
												   'glcrossword_line_right_bottom glcrossword_line_right_bottom_default',
													tx_glcrossword_box_questions::C_INT_DIR_DOWN_LEFT);
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(5 * $i_fltXScale);
		$l_intTop = $l_intTop + round(61 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlLeftArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
						 tx_glcrossword_box_questions::C_INT_DIR_DOWN_LEFT);
	
		return $l_strContent;
	}

	/**
	 * Get the arrow of the right to the top direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getRightTopArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow right to the top -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow line properties
		$l_intLeft = $l_intLeft + round(60 * $i_fltXScale);
		$l_intTop = $l_intTop + round(15 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(5 * $i_fltYScale);
	
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, 
												   'glcrossword_line_right_bottom glcrossword_line_right_bottom_default',
													tx_glcrossword_box_questions::C_INT_DIR_RIGHT_TOP);
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(60 * $i_fltXScale);
		$l_intTop = $l_intTop + round(5 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlTopArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, tx_glcrossword_box_questions::C_INT_DIR_RIGHT_TOP);
	
		return $l_strContent;
	}
	
	/**
	 * Get the right arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getRightArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
		
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow right -->' . "\n";
				
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
		
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(60 * $i_fltXScale);
		$l_intTop = $l_intTop + round(20 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
		
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlRightArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												  tx_glcrossword_box_questions::C_INT_DIR_RIGHT);
		
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of the right to the bottom direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getRightBottomArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
	
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow right to the bottom -->' . "\n";
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow line properties
		$l_intLeft = $l_intLeft + round(60 * $i_fltXScale);
		$l_intTop = $l_intTop + round(40 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(5 * $i_fltYScale);
	
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, 
												   'glcrossword_line_right_top glcrossword_line_right_top_default',
													tx_glcrossword_box_questions::C_INT_DIR_RIGHT_DOWN);
	
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
	
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(60 * $i_fltXScale);
		$l_intTop = $l_intTop + round(45 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
	
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlDownArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												 tx_glcrossword_box_questions::C_INT_DIR_RIGHT_DOWN);
	
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of the top to the left direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getTopLeftArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
		
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow top to the left -->' . "\n";
		
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
		
		// compute the arrow line properties
		$l_intLeft = $l_intLeft + round(15 * $i_fltXScale);
		$l_intTop = $l_intTop - round(10 * $i_fltYScale); 
		$l_intGeneralXSize = round(5 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
		
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, 
												   'glcrossword_line_right_top glcrossword_line_right_top_default',
													tx_glcrossword_box_questions::C_INT_DIR_TOP_LEFT);
		
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
		
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(5 * $i_fltXScale);
		$l_intTop = $l_intTop - round(20 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
		
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlLeftArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												 tx_glcrossword_box_questions::C_INT_DIR_TOP_LEFT);
		
		return $l_strContent;
	}
	
	/**
	 * Get the top arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getTopArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
		
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow top -->' . "\n";
				
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
		
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(20 * $i_fltXScale);
		$l_intTop = $l_intTop - round(10 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
		
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlTopArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, tx_glcrossword_box_questions::C_INT_DIR_TOP);
		
		return $l_strContent;
	}
	
	/**
	 * Get the arrow of the top to the right direction.
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getTopRightArrow($i_fltXScale, $i_fltYScale, $i_intBorderWidth) {
		// the HTML content
		$l_strContent = '';
		
		$l_strContent = "\n\t\t\t" . '<!-- Cell ' . $this->m_intX . 'x' . $this->m_intY . ' arrow top to the right -->' . "\n";
		
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
		
		// compute the arrow line properties
		$l_intLeft = $l_intLeft + round(40 * $i_fltXScale);
		$l_intTop = $l_intTop - round(10 * $i_fltYScale); 
		$l_intGeneralXSize = round(5 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
		
		// set the arrow line HTML content
		$l_strContent .= $this->getHtmlLineOfArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize, 
												   'glcrossword_line_left_top glcrossword_line_left_top_default',
													tx_glcrossword_box_questions::C_INT_DIR_TOP_RIGHT);
		
		// get the general box properties
		$this->getBoxProperties($i_fltXScale, $i_fltYScale, $i_intBorderWidth, $l_intLeft, $l_intTop, $l_intWidth, $l_intHeight);
		
		// compute the arrow properties
		$l_intLeft = $l_intLeft + round(45 * $i_fltXScale);
		$l_intTop = $l_intTop - round(20 * $i_fltYScale);
		$l_intGeneralXSize = round(10 * $i_fltXScale);
		$l_intGeneralYSize = round(10 * $i_fltYScale);
		
		// set the arrow HTML content
		$l_strContent .= $this->getHtmlRightArrow($l_intLeft, $l_intTop, $l_intGeneralXSize, $l_intGeneralYSize,
												  tx_glcrossword_box_questions::C_INT_DIR_TOP_RIGHT);
		
		return $l_strContent;
	}
	
	/**
	 * Get the plain HTML top arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @param integer	$i_intDirection		Direction of the arrow
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getHtmlTopArrow($i_intLeft, $i_intTop, $i_intGeneralXSize, $i_intGeneralYSize, $i_intDirection) {
		// the HTML content
		$l_strContent = '';
		// create the id of this arrow
		$l_strBoxId = 'arrow' . $this->m_intX . 'x' . $this->m_intY . 'x' . $i_intDirection . 
						'_' . $this->m_objCrossword->get_uniqueId();
		
		// set the arrow HTML content
		$l_strContent = "\t\t\t" . '<div class="glcrossword_triangle" id= "' . $l_strBoxId . 
				'" style="left: ' . $i_intLeft . 'px; top: ' .
				$i_intTop . 'px; border-bottom: ' . $i_intGeneralYSize . 'px; border-right: ' . $i_intGeneralXSize .
				'px; border-left: ' . $i_intGeneralXSize . 'px; border-bottom-style: solid; border-bottom-color: ' .
				'black; border-right-style: solid; border-right-color: transparent; border-left-style: solid; ' .
				'border-left-color: transparent;"></div>' . "\n";
	
		return $l_strContent;
	}
	
	/**
	 * Get the plain HTML bottom arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @param integer	$i_intDirection		Direction of the arrow
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getHtmlDownArrow($i_intLeft, $i_intTop, $i_intGeneralXSize, $i_intGeneralYSize, $i_intDirection) {
		// the HTML content
		$l_strContent = '';
		// create the id of this arrow
		$l_strBoxId = 'arrow' . $this->m_intX . 'x' . $this->m_intY . 'x' . $i_intDirection . 
						'_' . $this->m_objCrossword->get_uniqueId();
				
		// set the arrow HTML content
		$l_strContent = "\t\t\t" . '<div class="glcrossword_triangle" id= "' . $l_strBoxId . 
				'" style="left: ' . $i_intLeft . 'px; top: ' .
				$i_intTop . 'px; border-top: ' . $i_intGeneralYSize . 'px; border-right: ' . $i_intGeneralXSize .
				'px; border-left: ' . $i_intGeneralXSize . 'px; border-top-style: solid; border-top-color: ' .
				'black; border-right-style: solid; border-right-color: transparent; border-left-style: solid; ' .
				'border-left-color: transparent;"></div>' . "\n";
	
		return $l_strContent;
	}
	
	/**
	 * Get the plain HTML right arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @param integer	$i_intDirection		Direction of the arrow
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getHtmlRightArrow($i_intLeft, $i_intTop, $i_intGeneralXSize, $i_intGeneralYSize, $i_intDirection) {
		// the HTML content
		$l_strContent = '';
		// create the id of this arrow
		$l_strBoxId = 'arrow' . $this->m_intX . 'x' . $this->m_intY . 'x' . $i_intDirection . 
						'_' . $this->m_objCrossword->get_uniqueId();
		
		// set the arrow HTML content
		$l_strContent = "\t\t\t" . '<div class="glcrossword_triangle" id= "' . $l_strBoxId . 
						'" style="left: ' . $i_intLeft . 'px; top: ' . $i_intTop . 
						'px; border-top: ' . $i_intGeneralYSize . 'px; border-left: ' . $i_intGeneralXSize . 
						'px; border-bottom: ' . $i_intGeneralYSize . 'px; border-top-style: solid; border-top-color: ' . 
						'transparent; border-left-style: solid; border-left-color: black; border-bottom-style: solid; ' . 
						'border-bottom-color: transparent;"></div>' . "\n";
			
		return $l_strContent;
	}
	
	/**
	 * Get the plain HTML left arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @param integer	$i_intDirection		Direction of the arrow
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getHtmlLeftArrow($i_intLeft, $i_intTop, $i_intGeneralXSize, $i_intGeneralYSize, $i_intDirection) {
		// the HTML content
		$l_strContent = '';
		// create the id of this arrow
		$l_strBoxId = 'arrow' . $this->m_intX . 'x' . $this->m_intY . 'x' . $i_intDirection . 
						'_' . $this->m_objCrossword->get_uniqueId();
		
		// set the arrow HTML content
		$l_strContent = "\t\t\t" . '<div class="glcrossword_triangle" id= "' . $l_strBoxId . 
						'" style="left: ' . $i_intLeft . 'px; top: ' . $i_intTop . 
						'px; border-top: ' . $i_intGeneralYSize . 'px; border-right: ' . $i_intGeneralXSize . 
						'px; border-bottom: ' . $i_intGeneralYSize . 'px; border-top-style: solid; border-top-color: ' . 
						'transparent; border-right-style: solid; border-right-color: black; border-bottom-style: solid; ' . 
						'border-bottom-color: transparent;"></div>' . "\n";
					
		return $l_strContent;
	}
	
	/**
	 * Get the HTML of the line of a arrow
	 * @param float 	$i_fltXScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the width
	 * @param float 	$i_fltYScale 		Scale of the boxes 1 means 100% 0.5 means 50% of the height
	 * @param integer 	$i_intBorderWidth 	Thickness of the borderlines of the box
	 * @param integer	$i_intDirection		Direction of the arrowline
	 * @return string 						The HTML content of the arrow.
	 */
	protected function getHtmlLineOfArrow($i_intLeft, $i_intTop, $i_intGeneralXSize, $i_intGeneralYSize, $i_strLineType, $i_intDirection) {
		// the HTML content
		$l_strContent = '';
		// create the id of this arrowline
		$l_strBoxId = 'arrowline' . $this->m_intX . 'x' . $this->m_intY . 'x' . $i_intDirection . 
						'_' . $this->m_objCrossword->get_uniqueId();
		
		// set the arrow line HTML content
		$l_strContent = "\t\t\t" . '<div class="' . $i_strLineType . '" id="' . $l_strBoxId . '"' . 
						'style="left: ' . $i_intLeft . 'px; top: ' . $i_intTop . 'px; width: ' . $i_intGeneralXSize . 
						'px; height: ' . $i_intGeneralYSize . 'px;"></div>' . "\n";
							
		return $l_strContent;
	}
}


if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/glcrossword/pi1/class.tx_glcrossword_box_questions.php'])) {
	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/glcrossword/pi1/class.tx_glcrossword_box_questions.php']);
}

?>